@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# 鉴权失败，当前用户不允许执行该操作。
+AUTHFAILURE_UNAUTHORIZEDOPERATIONERROR = 'AuthFailure.UnauthorizedOperationError'
+
 # 禁止该操作。
 FAILEDOPERATION_NOTALLOWOPERATION = 'FailedOperation.NotAllowOperation'
 
@@ -29,6 +32,9 @@ INTERNALERROR = 'InternalError'
 # 添加异步任务失败。
 INTERNALERROR_ADDTASKERROR = 'InternalError.AddTaskError'
 
+# 内部调度系统错误。
+INTERNALERROR_CELERYERROR = 'InternalError.CeleryError'
+
 # cgw系统错误。
 INTERNALERROR_CGWSYSTEMERROR = 'InternalError.CgwSystemError'
 
@@ -44,9 +50,15 @@ INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 # 通信协议错误。
 INTERNALERROR_PROTOCOLERROR = 'InternalError.ProtocolError'
 
+# 未知的内部错误。
+INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'
+
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 参数值错误。
+INVALIDPARAMETER_BIZINVALIDPARAMETERVALUEERROR = 'InvalidParameter.BizInvalidParameterValueError'
+
 # 实例不存在。
 INVALIDPARAMETER_INSTANCENOTFOUND = 'InvalidParameter.InstanceNotFound'
 
@@ -59,12 +71,21 @@ LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 任务操作失败。
+OPERATIONDENIED_JOBOPERATIONDENIEDERROR = 'OperationDenied.JobOperationDeniedError'
+
+# 数据迁移服务不支持当前迁移类型。
+OPERATIONDENIED_MIGRATESERVICESUPPORTERROR = 'OperationDenied.MigrateServiceSupportError'
+
 # 该操作不能执行。
 OPERATIONDENIED_OPERATIONDENIED = 'OperationDenied.OperationDenied'
 
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# 未找到资源。
+RESOURCENOTFOUND_BIZRESOURCENOTFOUNDERROR = 'ResourceNotFound.BizResourceNotFoundError'
+
 # 迁移任务不存在。
 RESOURCENOTFOUND_JOBNOTEXIST = 'ResourceNotFound.JobNotExist'
 
